<?xml version="1.0" encoding="utf-8"?>
<!--
/**
 * Displays PRIDE XML as a set of HTML tables using EBI CSS rules.
 *
 * @author  Antony Quinn
 * @version $Id: pride.xsl,v 1.6 2007/11/09 16:11:53 martlenn Exp $
 * @note    The output from this stylesheet is included in another HTML page, so there are no HEAD or BODY sections.
 * @todo    Align numbers to right
 * @todo    Add entities? e.g. delta, nbsp ...etc
 *
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:output method="html"
                encoding="iso-8859-1"
                indent="yes"
                media-type="text/html"
                standalone="yes"/>

    <xsl:include href="mzdata.xsl"/>

    <!-- Title -->
    <xsl:template match="ExperimentCollection">
        <a name="top"></a>
        <table cellpadding="1px" border="1" style="{$style.table}">
            <tr>
                <th class="tablegreen" style="{$style.table.header}">
                    PRIDE Experiment Collection Version <xsl:value-of select="@version"/>
                </th>
            </tr>
            <xsl:apply-templates select="Experiment" mode="toc"/>
        </table>
        <xsl:apply-templates select="Experiment"/>
    </xsl:template>

    <!-- Table of contents -->
    <xsl:template match="Experiment" mode="toc">
        <tr>
            <td class="small">
                <a class ="red_boldsmall" href="#exp{position()}">
                    Experiment <xsl:value-of select="position()"/>: <xsl:value-of select="Title"/>
                </a>
			</td>
        </tr>
    </xsl:template>

    <!-- === Experiment === -->
    <xsl:template match="Experiment">
        <a name="exp{position()}"></a>
        <table cellpadding="1px" border="1" style="{$style.table}">
            <tr>
                <th class="smallbold" style="{$style.header}">
                    Experiment:
                    <br/>
                    <a href="#top" class="smallwhite2" style="font-weight:bold;text-decoration:none;">
                        (top <span style="font-size: 130%">&#8593;</span>)
                    </a>
                </th>
                <td colspan="2" class="small">
                    <table cellpadding="1px" border="0" class="tablegreen" width="100%">
                        <tr>
                            <td class="smallbold" style="{$style.table.header}"> Description: </td>
                            <td style="{$style.table.header}">
                                <xsl:value-of select="Title"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="smallbold" style="{$style.table.header}"> Short Title: </td>
                            <td class="small" style="{$style.table.header}">
                                <xsl:value-of select="ShortLabel"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="smallbold" style="{$style.table.header}"> Accession: </td>
                            <td class="small" style="{$style.table.header}">
                                <xsl:value-of select="ExperimentAccession"/>
                            </td>
                        </tr>
                    </table>
                </td>
            </tr>
			<tr>
				<th class="smallbold" style="{$style.header}">
                    Links:
                </th>
				<td colspan="2" class="small">
					<a class="red_boldsmall">
						<xsl:attribute name="href">#mzData<xsl:value-of select="ExperimentAccession"/></xsl:attribute>
						mzData Section (Tissue / sample details and Contact details)
					</a>
					<br/>
					<a class="red_boldsmall">
						<xsl:attribute name="href">#instrument<xsl:value-of select="ExperimentAccession"/></xsl:attribute>
						M/S Instrument details
					</a>
					<br/>
					<a class="red_boldsmall">
						<xsl:attribute name="href">#dataprocessing<xsl:value-of select="ExperimentAccession"/></xsl:attribute>
						Data processing details
					</a>
					<br/>
					<a class="red_boldsmall">
						<xsl:attribute name="href">#spectrumList<xsl:value-of select="ExperimentAccession"/></xsl:attribute>
						Spectrum List
					</a>
				</td>
			</tr>
			<tbody>
                <xsl:apply-templates select="current()[Reference]"  mode="reference"/>
                <xsl:apply-templates select="current()[Protocol]"   mode="protocol"/>
                <xsl:apply-templates select="current()[additional]" mode="additional"/>
            </tbody>
        </table>
        <xsl:apply-templates select="current()[GelFreeIdentification | TwoDimensionalIdentification]"
                             mode="identification"/>
        <xsl:apply-templates select="current()[descendant::*/PeptideItem]"
                             mode="peptide-item"/>
        <xsl:apply-templates select="mzData"/>
    </xsl:template>

    <!-- Literature references -->
    <xsl:template match="Experiment" mode="reference">
        <tr>
            <th rowspan="{count(Reference) + 1}" class="smallbold" style="{$style.header}">
                References:
            </th>
        </tr>
        <xsl:apply-templates select="Reference"/>
    </xsl:template>

    <!-- Protocol -->
    <xsl:template match="Experiment" mode="protocol">
	<tr>
            <th rowspan="{count(Protocol) + 1}" class="smallbold" style="{$style.header}">
                Protocol:
            </th>
        </tr>
        <xsl:apply-templates select="Protocol"/>
    </xsl:template>

    <!-- Additional -->
    <xsl:template match="Experiment" mode="additional">
	<tr>
            <th rowspan="2" class="smallbold" style="{$style.header}">
                Additional:
            </th>
        </tr>
        <tr>
            <td><xsl:apply-templates select="additional" mode="params"/></td>
        </tr>
    </xsl:template>

    <!-- === Literature reference === -->
    <xsl:template match="Reference">
        <tr>
            <td class="small">
                <xsl:apply-templates select="RefLine"/>
            </td>
            <td>
                <xsl:apply-templates select="additional" mode="params"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="RefLine">
        <xsl:value-of select="."/>
    </xsl:template>

    <!-- === Protocol === -->

    <xsl:template match="Protocol">
        <td class="small_bold" colspan="2">
            <table cellpadding="1px" border="1" style="{$style.table}">
                <tr>
                    <th class="smallbold">Name:</th>
                    <td class="small">
                        <xsl:value-of select="ProtocolName"/>
                    </td>
                </tr>
                <xsl:apply-templates select="ProtocolSteps/StepDescription"/>
            </table>
        </td>
    </xsl:template>

    <xsl:template match="StepDescription">
        <tr>
            <th class="smallbold">Step #<xsl:value-of select="position()"/></th>
            <td>
                <xsl:apply-templates select="." mode="params"/>
            </td>
        </tr>
    </xsl:template>

    <!-- === Identifications === -->

    <xsl:template match="Experiment" mode="identification">
        <table cellpadding="1px" border="1" style="{$style.table}">
            <tr>
                <th colspan="3" style="{$style.subheader}">
                    Identifications
                </th>
            </tr>
            <tr>
                <td colspan="3" class="small">
                    <table cellpadding="1px" border="1" style="{$style.table}">
                        <tr style="background-color: #dddddd">
                            <th class="smallbold">Accession</th>
                            <th class="smallbold">Splice Isoform</th>
                            <th class="smallbold">Database</th>
                            <th class="smallbold">Score</th>
                            <th class="smallbold">Threshold</th>
                            <th class="smallbold">Search Engine</th>
                            <th class="smallbold">Sequence Coverage</th>
                            <xsl:if test="TwoDimensionalIdentification">
                                <th class="smallbold">Gel Link</th>
                                <th class="smallbold">Molecular Weight</th>
                                <th class="smallbold">pI</th>
                            </xsl:if>
                            <th class="smallbold">
                                <table cellpadding="1px" border="1" style="{$style.table}">
                                    <tr style="background-color: #dddddd">
                                        <th class="smallbold" colspan="3">Additional Information</th>
                                    </tr>
                                    <tr style="background-color: #dddddd">
                                        <th width="10%" class="smallbold">Source</th>
                                        <th width="20%" class="smallbold">Name</th>
                                        <th width="70%" class="smallbold">Value</th>
                                    </tr>
                                </table>
                            </th>
                        </tr>
                        <xsl:apply-templates select="GelFreeIdentification | TwoDimensionalIdentification"/>
                    </table>
                </td>
            </tr>
        </table>
    </xsl:template>

    <xsl:template match="GelFreeIdentification | TwoDimensionalIdentification">
        <tr>
            <xsl:attribute name="style"><xsl:if test="position() mod 2 = 0">background-color:#ffffff</xsl:if></xsl:attribute>
            <!-- Add non-breaking space after optional elements -->
            <td class="small" align="center"><xsl:apply-templates select="Accession" mode="protein"/></td>
            <td class="small"><xsl:value-of select="SpliceIsoform"/><xsl:if test="not(SpliceIsoform)">&#160;</xsl:if></td>
            <td class="small"><xsl:value-of select="Database"/></td>
            <td class="small" align="right"><xsl:value-of select="Score"/><xsl:if test="not(Score)">&#160;</xsl:if></td>
            <td class="small"><xsl:value-of select="Threshold"/><xsl:if test="not(Threshold)">&#160;</xsl:if></td>
            <td class="small"><xsl:value-of select="SearchEngine"/><xsl:if test="not(SearchEngine)">&#160;</xsl:if></td>
            <td class="small" align="right"><xsl:apply-templates select="SequenceCoverage"/><xsl:if test="not(SequenceCoverage)">&#160;</xsl:if></td>
            <xsl:if test="name(.) = 'TwoDimensionalIdentification'">
                <td class="small" align="right"><xsl:if test="Gel/GelLink"><a><xsl:attribute name="target">blank</xsl:attribute><xsl:attribute name="href"><xsl:value-of select="Gel/GelLink"/></xsl:attribute>Gel link</a></xsl:if><xsl:if test="not(Gel/GelLink)">&#160;</xsl:if></td>
                <td class="small" align="right"><xsl:apply-templates select="MolecularWeight"/><xsl:if test="not(MolecularWeight)">&#160;</xsl:if></td>
                <td class="small" align="right"><xsl:value-of select="pI"/><xsl:if test="not(pI)">&#160;</xsl:if></td>
            </xsl:if>
            <td class="small">
                <table cellpadding="1px" border="1" width="100%">
                    <xsl:apply-templates select="additional/userParam | additional/cvParam"/>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="MolecularWeight">
        <xsl:value-of select="."/> kDA
    </xsl:template>

    <!-- Convert to percentage with no decimal places -->
    <xsl:template match="SequenceCoverage">
        <xsl:value-of select="format-number(number(.) * 100, '0')"/>%
    </xsl:template>

    <xsl:template match="GelLocation">
        <xsl:value-of select="concat(XCoordinate, ' x ', YCoordinate)"/>
    </xsl:template>

    <xsl:template match="Accession" mode="protein">
        <!-- Anchor added to allow the second listing of the protein to link to the first -->
        <a name="protein-{generate-id()}"></a>
        <xsl:apply-templates select="."/>
        <!-- If there are any peptides for this protein, internally link to the peptide list. -->
        <xsl:if test="../PeptideItem">
            <br/>
            <a class="red_boldsmall" href="#peptide-{generate-id()}">
                Peptide List
            </a>
        </xsl:if>
        <br/>
        <a href="#top" style="font-weight:bold;text-decoration:none;">
            (top <span style="font-size: 130%">&#8593;</span>)
        </a>
    </xsl:template>

    <xsl:template match="Accession" mode="peptide">
        <a name="peptide-{generate-id()}"></a>
        <xsl:apply-templates select="."/>
        <br/>
        <a class="red_boldsmall" href="#protein-{generate-id()}">
            Protein Detail
        </a>
        <br/>
        <a href="#top" style="font-weight:bold;text-decoration:none;">
            (top <span style="font-size: 130%">&#8593;</span>)
        </a>
    </xsl:template>

    <!-- Create link -->
    <xsl:template match="Accession">
        <xsl:variable name="url">
            <xsl:apply-templates mode="href">
                <xsl:with-param name="database" select="../Database"/>
                <xsl:with-param name="accession" select="."/>
            </xsl:apply-templates>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="string-length(normalize-space($url)) > 0">
                <a href="{normalize-space($url)}" title="{$url}"><xsl:value-of select="."/></a>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="."/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- === Peptide Items === -->

    <xsl:template match="Experiment" mode="peptide-item">
        <table cellpadding="1px" border="1" style="{$style.table}">
            <tr>
                <th colspan="3" style="{$style.subheader}">
                    Identification Peptide Lists
                </th>
            </tr>
            <xsl:apply-templates select="descendant::*[PeptideItem]" mode="peptide-item"/>
        </table>
    </xsl:template>

    <xsl:template match="node()[PeptideItem]" mode="peptide-item">
        <xsl:variable name="style"><xsl:if test="position() mod 2 = 0">background-color:#ffffff</xsl:if></xsl:variable>
        <tr style="{$style}">
            <td colspan="3" class="small">
                <table cellpadding="1px" border="1" width="100%">
                    <tr style="{$style}">
                        <td width="10%" class="small" align="center">
							<xsl:apply-templates select="Accession" mode="peptide"/>
						</td>
                        <td class="small">
                            <table cellpadding="1px" border="1" width="100%">
                                <xsl:apply-templates select="PeptideItem">
                                    <xsl:with-param name="style" select="$style"/>
                                </xsl:apply-templates>
                            </table>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
    </xsl:template>

	<xsl:template match="PeptideItem">


		<xsl:param name="spectrumId" select="SpectrumReference"/>
		<xsl:param name="mzDataSpectrumElement" select="../../mzData/spectrumList/spectrum/@id = SpectrumReference"/>
		<xsl:param name="expAccession" select="../../ExperimentAccession"/>
        <xsl:param name="experimid">
            <xsl:choose>
                <xsl:when test="$expAccession">e<xsl:value-of select="$expAccession"/></xsl:when>
                <xsl:otherwise></xsl:otherwise>
            </xsl:choose>
        </xsl:param>

		<xsl:param name="pepToSpecRef">
			<xsl:choose>
				<!-- Only generate an internal hyperlink if the referenced spectrum is present in the XML. -->
				<xsl:when test="$mzDataSpectrumElement">
					<xsl:value-of select="concat('#', $experimid, 's', $spectrumId)"/>
				</xsl:when>
                <xsl:otherwise></xsl:otherwise>
            </xsl:choose>
		</xsl:param>

		<xsl:param name="style" select="''"/>
        <tr>
            <td width="25%" rowspan="{count(current()[ModificationItem]) + 1}" class="smallbold">
                <xsl:value-of select="Sequence"/>
			</td>
            <td class="small">
                Location: <xsl:value-of select="concat(Start, ' - ', End)"/>
            </td>
            <td class="small">
                <xsl:choose>
                    <xsl:when test="SpectrumReference">
						Spectrum:
						<xsl:choose>
							<xsl:when test="$pepToSpecRef != ''">
								<a class="red_boldsmall" href="{$pepToSpecRef}">
									<xsl:value-of select="SpectrumReference"/>
								</a>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="SpectrumReference"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
                    <xsl:otherwise>
                        <xsl:attribute name="width">10%</xsl:attribute>
                        No spectrum reference
                    </xsl:otherwise>
				</xsl:choose>
			</td>
            <xsl:if test="additional">
                <td width="60%" class="small">
                    <xsl:apply-templates select="additional" mode="params">
                        <xsl:with-param name="style" select="$style"/>
                    </xsl:apply-templates>
                </td>
            </xsl:if>
        </tr>
        <xsl:apply-templates select="current()[ModificationItem]" mode="mod-item"/>
    </xsl:template>

    <xsl:template match="PeptideItem" mode="mod-item">
        <tr>
            <td class="smallbold" colspan="4">
                <table cellpadding="1px" border="1" width="100%">
                    <xsl:apply-templates select="ModificationItem"/>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="ModificationItem">
        <tr>
            <td class="small">
                Modification <xsl:value-of select="ModAccession"/>
                from database <xsl:value-of select="ModDatabase"/>
                [<xsl:value-of select="ModDatabaseVersion"/>]
                at position <xsl:value-of select="ModLocation"/>
            </td>
            <td style="width:20%" class="small">
                <xsl:apply-templates select="ModMonoDelta"/>
            </td>
            <td style="width:20%" class="small">
                <xsl:apply-templates select="ModAvgDelta"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="ModMonoDelta | ModAvgDelta">
        <xsl:choose>
            <xsl:when test="name(.) = 'ModMonoDelta'">Mono</xsl:when>
            <xsl:otherwise>Avg</xsl:otherwise>
        </xsl:choose>
        &#916;: <xsl:value-of select="."/>
        <xsl:if test="not(position() = last())"><br/></xsl:if>
    </xsl:template>

    <!-- Ignore all nodes and attributes that do not have an explicit template -->
    <xsl:template match="node() | @*" priority="-1">
        <xsl:apply-templates select="node() | @*"/>
    </xsl:template>

</xsl:stylesheet>
